From 431fce597e801ef85c582084f13236806c5ef55e Mon Sep 17 00:00:00 2001
From: batt <batt@38d2e660-2303-0410-9eaa-f027e97ec537>
Date: Wed, 23 Apr 2008 13:27:52 +0000
Subject: [PATCH] Fix a bug when 2 irqs on the same serial are pending: set lo
 level sensitive.

git-svn-id: https://src.develer.com/svnoss/bertos/trunk@1233 38d2e660-2303-0410-9eaa-f027e97ec537
---
 bertos/cpu/arm/drv/ser_at91.c | 8 ++++----
 1 file changed, 4 insertions(+), 4 deletions(-)

diff --git a/bertos/cpu/arm/drv/ser_at91.c b/bertos/cpu/arm/drv/ser_at91.c
index 74cca47b..f42af89d 100644
--- a/bertos/cpu/arm/drv/ser_at91.c
+++ b/bertos/cpu/arm/drv/ser_at91.c
@@ -287,8 +287,8 @@ static void uart0_init(
 	US0_IDR = 0xFFFFFFFF;
 	/* Set the vector. */
 	AIC_SVR(US0_ID) = uart0_irq_dispatcher;
-	/* Initialize to edge triggered with defined priority. */
-	AIC_SMR(US0_ID) = AIC_SRCTYPE_INT_EDGE_TRIGGERED | SERIRQ_PRIORITY;
+	/* Initialize to level sensitive with defined priority. */
+	AIC_SMR(US0_ID) = AIC_SRCTYPE_INT_LEVEL_SENSITIVE | SERIRQ_PRIORITY;
 	PMC_PCER = BV(US0_ID);
 
 	/*
@@ -382,8 +382,8 @@ static void uart1_init(
 	US1_IDR = 0xFFFFFFFF;
 	/* Set the vector. */
 	AIC_SVR(US1_ID) = uart1_irq_dispatcher;
-	/* Initialize to edge triggered with defined priority. */
-	AIC_SMR(US1_ID) = AIC_SRCTYPE_INT_EDGE_TRIGGERED | SERIRQ_PRIORITY;
+	/* Initialize to level sensitive with defined priority. */
+	AIC_SMR(US1_ID) = AIC_SRCTYPE_INT_LEVEL_SENSITIVE | SERIRQ_PRIORITY;
 	PMC_PCER = BV(US1_ID);
 
 	/*
-- 
2.34.1